==> fwbuilder_2.0.9.orig.tar.gz: fwbuilder-2.0.9/src/gui/pfAdvancedDialog.h <==
/* 

                          Firewall Builder

                 Copyright (C) 2004 NetCitadel, LLC

  Author:  Vadim Kurland     vadim@fwbuilder.org

  $Id: pfAdvancedDialog.h,v 1.5 2004/10/18 05:06:55 vkurland Exp $

  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/


#ifndef __PFADVANCEDDIALOG_H_
#define __PFADVANCEDDIALOG_H_

#include "pfadvanceddialog_q.h"
#include "DialogData.h"

namespace libfwbuilder {
    class FWObject;
};

class pfAdvancedDialog : public pfAdvancedDialog_q
{
    Q_OBJECT

    libfwbuilder::FWObject *obj;
    DialogData                       data;

 public:
    pfAdvancedDialog(QWidget *parent,libfwbuilder::FWObject *o);

protected slots:

    virtual void accept();
    virtual void reject();

    virtual void doScrubToggled();
    virtual void ltToggled();
    virtual void editProlog();
    virtual void editEpilog();

};

#endif // __PFADVANCEDDIALOG_H

==> fwbuilder_3.0.7.orig.tar.gz: fwbuilder-3.0.7/src/gui/pfAdvancedDialog.h <==
/* 

                          Firewall Builder

                 Copyright (C) 2004 NetCitadel, LLC

  Author:  Vadim Kurland     vadim@fwbuilder.org

  $Id: pfAdvancedDialog.h 453 2008-08-06 06:20:15Z vadim $

  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/


#ifndef __PFADVANCEDDIALOG_H_
#define __PFADVANCEDDIALOG_H_

#include <ui_pfadvanceddialog_q.h>
#include "DialogData.h"
#include <QDialog>

namespace libfwbuilder {
    class FWObject;
};

class pfAdvancedDialog : public QDialog
{
    Q_OBJECT

    libfwbuilder::FWObject *obj;
    DialogData              data;
    Ui::pfAdvancedDialog_q *m_dialog;

 public:
    pfAdvancedDialog(QWidget *parent,libfwbuilder::FWObject *o);
    ~pfAdvancedDialog();

protected slots:

    virtual void accept();
    virtual void reject();
    virtual void help();

    virtual void doScrubToggled();
    virtual void ltToggled();
    virtual void editProlog();
    virtual void editEpilog();

};

#endif // __PFADVANCEDDIALOG_H
